# coding=utf-8
from datetime import datetime

from aio_client.configs import DEBUG_MODE
from aio_client.consumer.api import push_request
from aio_client.consumer.models import PostConsumerRequest
from concentrator import settings
from concentrator.smev3 import kinder_conc_event
from concentrator.smev3.base.utils import (CustomStringIO, generate_message_id,
                                           get_order_id)


def get_info_event_request(order_id, event):
    """Запрос на событие.

    :param order_id: ID заявки на портале
    :param event: Событие
    """
    request = kinder_conc_event.EventServiceRequestType(
        env=settings.EVENT_SERVICE_ENV,
        orderId=order_id,
        eventDate=datetime.now(),
        eventComment=event.comment,
        event=kinder_conc_event.EventType(
            infoEvent=kinder_conc_event.InfoEventType(
                code=event.code
            )
        )
    )

    mystdout = CustomStringIO()
    request.export(
        mystdout, 0, name_='eventServiceRequest', pretty_print=False)
    return mystdout.getvalue()


def push_info_event(order_id, event, attachments=''):
    """Отправка запроса с событием.

    :param order_id: ID заявки на портале
    :param event: Событие
    :param attachments: Прикрепленные файлы
    """
    request = PostConsumerRequest(
        message_id=generate_message_id(),
        body=get_info_event_request(order_id, event),
        message_type=settings.EVENT_SERVICE_MESSAGE_TYPE,
        attachments=attachments,
        is_test_message=DEBUG_MODE
    )

    response = push_request(request)

    return response


def get_event_data(declaration, event):
    """Получение данных события.

    :param declaration: Заявка
    :param event: Событие
    """
    return get_order_id(declaration), event
